select
  an.numero as numero_matriz
  , an.dtnascimento nascimento_matriz
  , an.dtentfazenda data_entrada_fazenda
  , par.data as data_parto_analisado
  , tpar.descricao as tipo_parto_analisado
  , auxpar.descricao as grau_auxilio_parto_analisado
  , cob.data as data_concepcao
  , (case
      when (cob.cdtiporeproducao = '1') then 'IA'
      when (cob.cdtiporeproducao = '2') then 'Cob'
      when (cob.cdtiporeproducao = '3') then 'FIV_TE'
    else null end) as tipo_concepcao
  , pes.nome as inseminador
  , (par.data - cob.data) as per_serv_ou_dias_ab
  , (select count (*)
    from reproducao re
    where re.cdanimal = an.cdanimal
      and re.cdtiporeproducao in (1,2,3)
      and re.data <= (coalesce(par.data,current_date))
      and re.data > (coalesce(up.data, '1900-01-01'))
      and re.data <= cob.data) as numero_tentativas
  , ((select count(*)
      from reproducao re
      where re.cdanimal = an.cdanimal
      and re.data <= cob.data
      and re.cdtiporeproducao = 7)
    + 1 + coalesce(an.numpartoentrada, 0))as ordem_parto_analisado
  , tou.numero as reprodutor
  , maeemb.numero as doadora
  , paiemb.numero as pai_embriao
  , (select grausangue
    from sp_calculagrausangue(an.cdanimal)) as grau_sangue_matriz
  , (select producao305 from sp_producao305(lac.cdlactacao)) as producao_305
  , (select producaototal from sp_calculaproducaototal(lac.cdlactacao,lac.dtfim))as producao_total
  , (case
      when (par.retencaoplacenta = '1') then 'Sim'
      when (par.retencaoplacenta = '0') then 'No'
    else null end) as retencao_placenta_parto_atual
  , (case
      when (up.retencaoplacenta = '1') then 'Sim'
      when (up.retencaoplacenta = '0') then 'No'
    else null end) as retencao_placenta_ultimo_parto
  , (cob.data - up.data) as del_na_concpecao
  , (lac.dtfim - lac.dtinicio) as duracao_lactacao
  , lac.dtfim as data_secagem
  , up.data as data_parto_anterior
  , (par.data - up.data) as difer_parto_atual_ant
  , (select first 1 re.valor
    from medida re
    where re.cdanimal = par.cdanimal
      and re.cdtipomedida = 2
      and re.dtmedida = par.data
    order by re.dtmedida desc) as escore_parto
    ,(case when (select count (*) from doencaanimal doa where doa.cdanimal=cob.cdanimal and doa.cddoenca in (select cddoenca from doenca where upper(nomeresumido) like '%CASCO%') and doa.dtinicio between lac.dtinicio and lac.dtfim) >0 then 'Sim' else null end) as casco_na_lactacao
    ,(case when (select count (*) from doencaanimal doa where doa.cdanimal=cob.cdanimal and doa.cddoenca in (select cddoenca from doenca where upper(nomeresumido) like '%HIPOCALCEMIA%') and doa.dtinicio between lac.dtinicio and lac.dtfim) >0 then 'Sim' else null end) as hipocalcemia_na_lactacao
    ,(case when (select count (*) from doencaanimal doa where doa.cdanimal=cob.cdanimal and doa.cddoenca in (select cddoenca from doenca where upper(nomeresumido) like '%CETOSE%') and doa.dtinicio between lac.dtinicio and lac.dtfim) >0 then 'Sim' else null end) as cetose_na_lactacao
    ,(case when (select count (*) from doencaanimal doa where doa.cdanimal=cob.cdanimal and doa.cddoenca in (select cddoenca from doenca where upper(nomeresumido) like '%DESLOCAMENTO DE ABOMASO%') and doa.dtinicio between lac.dtinicio and lac.dtfim) >0 then 'Sim' else null end) as deslocamento_abomaso_na_lactacao
    ,(case when (select count (*) from doencaanimal doa where doa.cdanimal=cob.cdanimal and doa.cddoenca in (select cddoenca from doenca where upper(nomeresumido) like '%PNEUMONIA%') and doa.dtinicio between lac.dtinicio and lac.dtfim) >0 then 'Sim' else null end) as pneumonia_na_lactacao
from
  animal an
  join reproducao par on par.cdtiporeproducao = 7 and par.cdanimal = an.cdanimal
  left join tipoparto tpar on tpar.cdtipoparto = par.cdtipoparto
  left join auxilioparto auxpar on auxpar.cdauxilioparto = par.cdauxilioparto
  join reproducao cob on cob.cdreproducao =
    (select first 1 re.cdreproducao
    from reproducao re
    where re.data < par.data
      and re.cdtiporeproducao in (1,2,3)
      and re.cdanimal = par.cdanimal
    order by re.data desc)
  left join reproducao up on up.cdreproducao =
    (select first 1 re.cdreproducao
    from reproducao re
    where re.cdanimal = an.cdanimal
      and re.cdtiporeproducao = 7
      and re.data < cob.data
    order by re.data desc)
  left join animal tou on tou.cdanimal = cob.cdreprodutor
  left join animal emb on emb.cdanimal = cob.cdembriao
  left join animal maeemb on maeemb.cdanimal = emb.cdmae
  left join animal paiemb on paiemb.cdanimal = emb.cdpai
  left join lactacao lac on lac.cdlactacao =
    (select first 1 rel.cdlactacao
    from lactacao rel
    where rel.cdanimal = an.cdanimal
      and rel.dtinicio = par.data)
  left join pessoa pes on pes.cdpessoa = cob.cdpessoa
where
---- MATRIZES ATIVAS
  an.dtbaixa is null
----- PARTOS A PARTIR DE - INFORMAR A DATA INICIAL DOS PARTOS DESEJADOS NO FORMATO aaaa-mm-dd
  and par.data >='2015-01-01'
order by
  an.numordenado, par.data
